# coding: utf-8

"""
    BOAVIZTAPI - DEMO

    <p>🎯 Retrieving the impacts of digital elements.</p> <p>This is a quick demo, to see full documentation <a href=\"https://doc.api.boavizta.org\">click here</a></p> <h2>Features</h2> <p>Bellow a list of all available features.</p> <h3>👄 Verbose</h3> <p>Verbose is an HTTP parameter. If set at true :</p> <ul> <li>Shows the impacts of each component</li> <li>Shows the value used for each attribute</li> </ul> <p><em>\"attribute\": {\"value\": \"value\", \"unit\": \"unit\", \"status\": \"Status\", \"source\": \"Source\", \"min\":\"min\", \"max\":\"max\", \"significant_figures\":\"significant_figures\"}</em></p> <h3>🔨 Embedded</h3> <ul> <li>Embedded impacts are the impacts occurring during raw material extraction, manufacture, distribution and end of life</li> <li>When end of life is not taken into account, we specified it in the <code>warnings</code></li> </ul> <h3>🔌  Usage</h3> <p>Usage impacts are assessed by multiplying :</p> <ul> <li> <p>a <strong>duration</strong></p> </li> <li> <p>an <strong>impact factor</strong> </p> </li> <li> <p>an <strong>electrical consumption</strong> </p> </li> </ul> <h4>⏲ Duration</h4> <p>Usage impacts can be given as a router parameter, in hours.</p> <p>If no duration is given, <strong>the impact is assess for the all life duration of the asset</strong>.</p> <h4>✖️ Impact factors</h4> <ul> <li>Impact factors can be given : <em>\"usage\":{\"elec_factors\":{[criteria]: 0.38}}</em></li> <li> <p>Impact factors can be retrieved from : <em>\"usage\":{\"usage_location\": \"FRA\"}</em>. </p> </li> <li> <p>See the list of locations : <a href=\"/v1/utils/country_code\">/v1/utils/country_code</a>*</p> </li> </ul> <h4>⚡ Electrical consumption</h4> <h5>⏺️ Given</h5> <ul> <li>Electrical consumption can be given for one hour (average) <em>\"usage\":{\"avg_power\": 1}</em>.</li> </ul> <h5>📈 Modeled</h5> <ul> <li>Electrical consumption can be retrieved from consumption profile using <em>usage:{time_workload: 50}</em>.</li> </ul> <h5>📋 Archetype</h5> <ul> <li>In some cases, default electrical consumption can be taken from the archetype</li> </ul> <h3>🔃 Auto-complete &amp; 📋 Archetype</h3> <p>The API will complete the missing attributes in a request with a completion function or with values taken from the <code>archetype</code> specified in the route parameter.</p> <h3>⏬ Allocation</h3> <ul> <li>Usage impacts are assessed on the duration given in route parameter</li> <li>Embedded impacts are allocated linearly on the duration given in parameter <code>embedded_impact = impact * (duration/life_duration)</code></li> </ul> <p>If no duration is given, the life_duration (<code>`hours_life_time</code>) of the asset is used.</p>

    The version of the OpenAPI document: 1.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from boaviztapi_sdk.api.component_api import ComponentApi


class TestComponentApi(unittest.TestCase):
    """ComponentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ComponentApi()

    def tearDown(self) -> None:
        pass

    def test_case_all_archetype_name_v1_component_case_archetype_get(self) -> None:
        """Test case for case_all_archetype_name_v1_component_case_archetype_get

        Case All Archetype Name
        """
        pass

    def test_case_archetype_config_v1_component_case_archetype_config_get(self) -> None:
        """Test case for case_archetype_config_v1_component_case_archetype_config_get

        Case Archetype Config
        """
        pass

    def test_case_impact_bottom_up_v1_component_case_get(self) -> None:
        """Test case for case_impact_bottom_up_v1_component_case_get

        Case Impact Bottom Up
        """
        pass

    def test_case_impact_bottom_up_v1_component_case_post(self) -> None:
        """Test case for case_impact_bottom_up_v1_component_case_post

        Case Impact Bottom Up
        """
        pass

    def test_cpu_all_archetype_name_v1_component_all_get(self) -> None:
        """Test case for cpu_all_archetype_name_v1_component_all_get

        Cpu All Archetype Name
        """
        pass

    def test_cpu_all_archetype_name_v1_component_cpu_archetype_get(self) -> None:
        """Test case for cpu_all_archetype_name_v1_component_cpu_archetype_get

        Cpu All Archetype Name
        """
        pass

    def test_cpu_archetype_config_v1_component_cpu_archetype_config_get(self) -> None:
        """Test case for cpu_archetype_config_v1_component_cpu_archetype_config_get

        Cpu Archetype Config
        """
        pass

    def test_cpu_impact_bottom_up_v1_component_cpu_get(self) -> None:
        """Test case for cpu_impact_bottom_up_v1_component_cpu_get

        Cpu Impact Bottom Up
        """
        pass

    def test_cpu_impact_bottom_up_v1_component_cpu_post(self) -> None:
        """Test case for cpu_impact_bottom_up_v1_component_cpu_post

        Cpu Impact Bottom Up
        """
        pass

    def test_disk_impact_bottom_up_v1_component_hdd_get(self) -> None:
        """Test case for disk_impact_bottom_up_v1_component_hdd_get

        Disk Impact Bottom Up
        """
        pass

    def test_disk_impact_bottom_up_v1_component_hdd_post(self) -> None:
        """Test case for disk_impact_bottom_up_v1_component_hdd_post

        Disk Impact Bottom Up
        """
        pass

    def test_disk_impact_bottom_up_v1_component_ssd_get(self) -> None:
        """Test case for disk_impact_bottom_up_v1_component_ssd_get

        Disk Impact Bottom Up
        """
        pass

    def test_disk_impact_bottom_up_v1_component_ssd_post(self) -> None:
        """Test case for disk_impact_bottom_up_v1_component_ssd_post

        Disk Impact Bottom Up
        """
        pass

    def test_hdd_all_archetype_name_v1_component_hdd_archetype_get(self) -> None:
        """Test case for hdd_all_archetype_name_v1_component_hdd_archetype_get

        Hdd All Archetype Name
        """
        pass

    def test_hdd_archetype_config_v1_component_hdd_archetype_config_get(self) -> None:
        """Test case for hdd_archetype_config_v1_component_hdd_archetype_config_get

        Hdd Archetype Config
        """
        pass

    def test_motherboard_all_archetype_name_v1_component_motherboard_archetype_get(self) -> None:
        """Test case for motherboard_all_archetype_name_v1_component_motherboard_archetype_get

        Motherboard All Archetype Name
        """
        pass

    def test_motherboard_archetype_config_v1_component_motherboard_archetype_config_get(self) -> None:
        """Test case for motherboard_archetype_config_v1_component_motherboard_archetype_config_get

        Motherboard Archetype Config
        """
        pass

    def test_motherboard_impact_bottom_up_v1_component_motherboard_get(self) -> None:
        """Test case for motherboard_impact_bottom_up_v1_component_motherboard_get

        Motherboard Impact Bottom Up
        """
        pass

    def test_motherboard_impact_bottom_up_v1_component_motherboard_post(self) -> None:
        """Test case for motherboard_impact_bottom_up_v1_component_motherboard_post

        Motherboard Impact Bottom Up
        """
        pass

    def test_power_supply_all_archetype_name_v1_component_power_supply_archetype_get(self) -> None:
        """Test case for power_supply_all_archetype_name_v1_component_power_supply_archetype_get

        Power Supply All Archetype Name
        """
        pass

    def test_power_supply_archetype_config_v1_component_power_supply_archetype_config_get(self) -> None:
        """Test case for power_supply_archetype_config_v1_component_power_supply_archetype_config_get

        Power Supply Archetype Config
        """
        pass

    def test_power_supply_impact_bottom_up_v1_component_power_supply_get(self) -> None:
        """Test case for power_supply_impact_bottom_up_v1_component_power_supply_get

        Power Supply Impact Bottom Up
        """
        pass

    def test_power_supply_impact_bottom_up_v1_component_power_supply_post(self) -> None:
        """Test case for power_supply_impact_bottom_up_v1_component_power_supply_post

        Power Supply Impact Bottom Up
        """
        pass

    def test_ram_all_archetype_name_v1_component_ram_archetype_get(self) -> None:
        """Test case for ram_all_archetype_name_v1_component_ram_archetype_get

        Ram All Archetype Name
        """
        pass

    def test_ram_archetype_config_v1_component_ram_archetype_config_get(self) -> None:
        """Test case for ram_archetype_config_v1_component_ram_archetype_config_get

        Ram Archetype Config
        """
        pass

    def test_ram_impact_bottom_up_v1_component_ram_get(self) -> None:
        """Test case for ram_impact_bottom_up_v1_component_ram_get

        Ram Impact Bottom Up
        """
        pass

    def test_ram_impact_bottom_up_v1_component_ram_post(self) -> None:
        """Test case for ram_impact_bottom_up_v1_component_ram_post

        Ram Impact Bottom Up
        """
        pass

    def test_ssd_all_archetype_name_v1_component_ssd_archetype_get(self) -> None:
        """Test case for ssd_all_archetype_name_v1_component_ssd_archetype_get

        Ssd All Archetype Name
        """
        pass

    def test_ssd_archetype_config_v1_component_ssd_archetype_config_get(self) -> None:
        """Test case for ssd_archetype_config_v1_component_ssd_archetype_config_get

        Ssd Archetype Config
        """
        pass


if __name__ == '__main__':
    unittest.main()
